Solitude Carrom Playing — SoL 4 user manual

# Solitude Carrom Playing

During the first months of the year 2020 all humanity faced an impetuous healthcare emergency: probably for the first time in history, all human activities in all the populated areas of the planet have been overwhelmed, and while I'm writing nobody knows yet about how long it will last, let alone what the social and economic consequences will be in the long-term.

My thoughts go out to the families of the hundreds of thousands of victims and at the same time to all the people who face the pandemic by risking their own health for the sake of the others and jeopardizing the life of their loved ones.

## Corona Carrom

Since basically the only defense we can apply is that of the social distancing and that all group play activities have been suspended indefinitely, the Carrom players have adapted, inventing a different competitive mode to the normal tournaments, based on a variant of the game known as “Danwei Grade” used mainly as a workout.

Stay at home and practice!

### Rules of the game

Your match must be recorded live on the appropriate `Facebook` group:

- go to your appointed group

- click on `Live Video` in the top of the page

- click `Start Video` when you are ready to play

1. Arrange the coins on the carrom board. During the game you must pocket all the black and white coins without any order. The red queen can be pocketed anytime and you don't have to cover the queen.

2. Break and start to count the number of strokes that that you fail to pocket (miss).

3. If in the break you succeed to pocket one or more coins then the strokes count is 0 (zero). If you failed to pocket in break then add the stroke count of 1 (one).

4. In every following turn, if you pocket, then the count does not increase until you fail to pocket a coin. Add the count 1 (one) whenever you fail to pocket.

   Follow the official rule of Due and Double Due:

   Due

     take out 1 coin and place in the circle on the opposite side from you and add 1 to the count

   Double Due

     take out 2 coins and place them horizontally touching each other anywhere in the circle without adding the count

5. First board finishes when you pocket all 18 coins and the queen. Note the count of misses you made to finish the first board.

6. Repeat above test for 4 boards and note count of missed strokes in each board.

7. Eventually, visit the SoL page at the URL you received by email, insert the counters in the form and confirm it.